@@ -114,18 +114,18 @@ impl Emitter {
     ///
     /// # Errors
     ///
-    /// Returns a [`EmitJsonError::EventTypeUnknown`] error type if the
+    /// Returns a [`EmitJsonErrorType::EventTypeUnknown`] error type if the
     /// event type is unknown.
     ///
-    /// Returns a [`EmitJsonError::Parsing`] error type if the combination of
-    /// the provided opcode, sequence, event type, and JSON could not be parsed
-    /// into an event.
+    /// Returns a [`EmitJsonErrorType::Parsing`] error type if the combination
+    /// of the provided opcode, sequence, event type, and JSON could not be
+    /// parsed into an event.
     pub fn json(
         &self,
         op: u8,
         seq: Option<u64>,
         event_type: Option<&str>,
-        json: &mut str,
+        json: &mut [u8],
     ) -> Result<(), EmitJsonError> {
         let flag = EventTypeFlags::try_from((op, event_type)).map_err(|(op, event_type)| {
             EmitJsonError {
